@@ -15,7 +15,8 @@ impl ExampleSecretsResolver {
     }
 }
 
-#[async_trait]
+#[cfg_attr(feature = "uniffi", async_trait)]
+#[cfg_attr(not(feature = "uniffi"), async_trait(?Send))]
 impl SecretsResolver for ExampleSecretsResolver {
     async fn get_secret(&self, secret_id: &str) -> Result<Option<Secret>> {
         Ok(self
